@@ -1,17 +1,16 @@
 ;; dinotrace.el --- minor mode for displaying waveform signal values
-;;
-;; $Id: dinotrace.el 29145 2006-12-26 16:33:54Z wsnyder $
 
 ;; Author          : Wilson Snyder <wsnyder@wsnyder.org>
 ;; Keywords        : languages
+;; version: 9.4c
 
 ;;; Commentary:
 ;;
 ;; Distributed from the web
-;;	http://www.veripool.com
+;;	http://www.veripool.org
 ;;
 ;; This also requires verilog-mode.el from
-;; 	http://www.surefirev.com/
+;; 	http://www.veripool.org
 ;;
 ;; To use this package, simply put it in a file called "dinotrace.el" in
 ;; a Lisp directory known to Emacs (see `load-path').
@@ -83,34 +82,27 @@
 ;;
 ;; Dinotrace.el is free software; you can redistribute it and/or modify
 ;; it under the terms of the GNU General Public License as published by
-;; the Free Software Foundation; either version 2, or (at your option)
+;; the Free Software Foundation; either version 3, or (at your option)
 ;; any later version.
 ;;
 ;; Dinotrace.el is distributed in the hope that it will be useful,
 ;; but WITHOUT ANY WARRANTY; without even the implied warranty of
 ;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 ;; GNU General Public License for more details.
-;; 
+;;
 ;; You should have received a copy of the GNU General Public License
 ;; along with Dinotrace; see the file COPYING.  If not, write to
 ;; the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 ;; Boston, MA 02111-1307, USA.
 
 ;;; History:
-;; 
+;;
 
 ;;; Code:
 
 (require 'verilog-mode)
 
-(or (string-match "^[0-9]+$" verilog-mode-version)  ; Subversion
-    (string-match "Revision: [456789]" verilog-mode-version)
-    (string-match "Revision: 3\.[2-9][0-9]" verilog-mode-version)
-    (string-match "Revision: 3\.1[3-9]" verilog-mode-version)
-    (string-match "Revision: 3\.12\.1" verilog-mode-version)
-    (error "Need verilog-mode Revision 3.13 or newer.  You have %s" verilog-mode-version))
-
-(defconst dinotrace-mode-version "$$Revision: 29145 $$"
+(defconst dinotrace-mode-version "9.4c"
   "Version of this dinotrace-mode.")
 
 (eval-when-compile
@@ -171,7 +163,8 @@ before raising error.")
   "Face name to use for cursors, etc that are in default foreground color.")
 (defface dinotrace-foreground-face
   '((t (:bold t :underline t)))
-  "Default face to use for cursors, etc that are in default foreground color.")
+  "Default face to use for cursors, etc that are in default foreground color."
+  :group 'dinotrace-mode)
 
 (defconst dinotrace-languages
   ;;     mode         annnotate
@@ -183,13 +176,13 @@ before raising error.")
 		      verilog-read-signals
 		      dinotrace-nop
 		      dinotrace-annotate-verilog-signal
-		      dinotrace-annotate-verilog-value) 
+		      dinotrace-annotate-verilog-value)
 
      ( sim-log-mode   dinotrace-annotate-sim-log-buffer
 		      nil
 		      dinotrace-annotate-sim-log-cursor
 		      dinotrace-annotate-verilog-signal
-		      dinotrace-annotate-verilog-value) 
+		      dinotrace-annotate-verilog-value)
 
      ( c-mode  	      dinotrace-annotate-verilog-buffer
 		      dinotrace-c-read-signals
@@ -243,8 +236,7 @@ that buffer type.")
   (substitute-key-definition `toggle-read-only 'dinotrace-toggle-read-only
 			     dinotrace-mode-map global-map)
   (substitute-key-definition `hilit-recenter 'recenter ;; Slow and useless
-			     dinotrace-mode-map global-map)
-  )
+			     dinotrace-mode-map global-map))
 
 ;;
 ;; Menus
@@ -358,7 +350,7 @@ Created in the annotation file by dinotrace.")
 Created in the annotation file by dinotrace.")
 
 ;;
-;; Array element Macros 
+;; Array element Macros
 ;;
 
 (defsubst dinotrace-buffer-annotate-func ()
@@ -469,7 +461,7 @@ exit dinotrace-mode.
 To unannotate the buffer, use:
    \\[dinotrace-unannotate-buffer]	dinotrace-unannotate-buffer
    \\[dinotrace-unannotate-all]	dinotrace-unannotate-all
- or, toggle read-only with \\[dinotrace-toggle-read-only] 
+ or, toggle read-only with \\[dinotrace-toggle-read-only]
 
 These bindings are added to the buffer's keymap when you enter this mode:
 Mostly, the last letters in these commands match the Dinotrace program keys.
@@ -576,7 +568,7 @@ If dinotrace annotated, then remove annotation also."
 ;; Alias for verilog-mode 3.10 back compatibility
 (defun dinotrace-unannotate-all-buffers ()
   (dinotrace-unannotate-all))
-  
+
 (defun dinotrace-unannotate-buffer (&optional buffer)
   "Remove `value' comments for current buffer.
 This is just a revert-buffer which keeps the window and point in a
@@ -644,7 +636,7 @@ similar place."
 ;;
 ;; Annotation
 ;;
-      
+
 (defun dinotrace-reannotate-all-windows ()
   "Check annotations in all buffers, update those that need it."
   (interactive)
@@ -677,7 +669,7 @@ similar place."
 	  (setq minor-mode-map-alist
 		(cons (cons 'dinotrace-mode dinotrace-mode-map)
 		      minor-mode-map-alist))))
-    
+
     (when (and (assoc major-mode dinotrace-languages)
 	       (not dinotrace-mode)
 	       (or (cond ((not (buffer-modified-p)) t)
@@ -694,10 +686,10 @@ similar place."
       (set (make-local-variable 'fontification-functions) nil) ;; else emacs21 will font-lock what we insert
       (dinotrace-save-mod-excursion
        ;;
-       (set (make-variable-buffer-local 'dinotrace-buffer-read-only)  SAVE-read-only)  ;; set in save-mod-excursion
-       (set (make-variable-buffer-local 'dinotrace-buffer-string) (buffer-string))
-       (set (make-variable-buffer-local 'dinotrace-buffer-annotate-time) dinotrace-annotate-time)
-       (make-variable-buffer-local 'dinotrace-buffer-hierarchy-regexp)
+       (set (make-local-variable 'dinotrace-buffer-read-only)  SAVE-read-only)  ;; set in save-mod-excursion
+       (set (make-local-variable 'dinotrace-buffer-string) (buffer-string))
+       (set (make-local-variable 'dinotrace-buffer-annotate-time) dinotrace-annotate-time)
+       (make-local-variable 'dinotrace-buffer-hierarchy-regexp)
        (setq SAVE-read-only t)
        ;;
        (let ((case-fold-search nil)
@@ -712,7 +704,7 @@ similar place."
 	 (force-mode-line-update)
 	 (message "Done.")
 	 )))))
-	  
+
 (defun dinotrace-set-text-properties (start end face &optional object)
   "Call set-text-properties."
   (set-text-properties start end
@@ -754,7 +746,7 @@ similar place."
 	  (dinotrace-insert-faced tim-str (dinotrace-cursor-face cursor-num))
 	  (setq cursor-num (1+ cursor-num))))
       (dinotrace-insert-faced "'\n" dinotrace-header-face)))
-  (set (make-variable-buffer-local 'dinotrace-buffer-header-lines)
+  (set (make-local-variable 'dinotrace-buffer-header-lines)
        (count-lines 1 (point))))
 
 (defsubst dinotrace-annotate-buffer-signal (sig)
@@ -882,7 +874,7 @@ Point must be at proper start position (or point-min)"
   (let ((ctimen (string-to-number ctime))
 	max-point)
     (while (and (re-search-forward sim-log-time-regexp nil t)
-		(> ctimen (string-to-int (match-string 1)))))
+		(> ctimen (string-to-number (match-string 1)))))
     ;; Skip blanks
     (forward-line 0)
     (setq max-point (point))
@@ -915,7 +907,7 @@ like \"notafoo12\"."
 ;;
 ;; Quick Annotation - Do all buffers when user hits cursor or signal keys
 ;;
-      
+
 (defun dinotrace-nop (&rest foo))
 
 ;; Quickly add cursor time to all log buffers
@@ -929,7 +921,7 @@ like \"notafoo12\"."
 			     (funcall (dinotrace-buffer-quick-cursor-func)
 				      ctime face))))))
 	    (buffer-list))))
-  
+
 ;; Quickly highlight a signal
 (defun dinotrace-quickannotate-signal (signal color)
   (let ((face (dinotrace-sigcolor-face color))
@@ -975,20 +967,20 @@ Returns T if the file has changed."
   (cond ((not (file-readable-p filename))
 	 (message "Annotation file no longer exists!")
 	 nil)
-	((equal dinotrace-annotate-time 
+	((equal dinotrace-annotate-time
 		(nth 5 (file-attributes filename)))
 	 nil)
 	(t
 	 (message "Reading annotation file %s" filename)
 	 (load-file filename)
-	 (setq dinotrace-annotate-time 
+	 (setq dinotrace-annotate-time
 	       (nth 5 (file-attributes filename)))
 	 ;;
 	 ;; Make a face for each cursor
 	 (let ((cursor-num 0))
 	   (while (< cursor-num (length dinotrace-cursors))
 	     (dinotrace-cursor-set-face
-	      cursor-num 
+	      cursor-num
 	      (or (and (not (equal "" (dinotrace-cursor-color-name cursor-num)))
 		       (dinotrace-face-create
 			(dinotrace-cursor-color-name cursor-num)
@@ -1000,7 +992,7 @@ Returns T if the file has changed."
 	 (let ((color-num 0))
 	   (while (< color-num (length dinotrace-signal-colors))
 	     (dinotrace-sigcolor-set-face
-	      color-num 
+	      color-num
 	      (or (and (not (equal "" (dinotrace-sigcolor-color-name color-num)))
 		       (dinotrace-face-create
 			(dinotrace-sigcolor-color-name color-num)
@@ -1015,10 +1007,10 @@ Returns T if the file has changed."
 	      (car sigs) (dinotrace-make-propertied (car sigs)))
 	     (setq sigs (cdr sigs))))
 	 t)))
-      
+
 (defun dinotrace-face-create (color italic)
   (let ((face (intern (concat "dinotrace-" color (if italic "-italic" "")))))
-    (cond ((internal-find-face face))
+    (cond ((facep face))
 	  ((make-face face)
 	   (set-face-foreground face color)
 	   (set-face-italic-p face italic)
@@ -1066,7 +1058,7 @@ dinotrace-read-timout time."
 ;;
 ;; Command sending utilities
 ;;
-      
+
 (defun dinotrace-find-time-default (point)
   "Find a time near the cursor.  Works in sim-log-mode."
   (save-excursion
@@ -1121,7 +1113,7 @@ dinotrace-read-timout time."
 ;;
 ;; Socket Interactive functions
 ;;
-      
+
 (defun dinotrace-goto-time (point)
   "Goto the time described after POINT.
 For example if point is before [1162], it will goto 1162."
@@ -1270,7 +1262,7 @@ If prefix-arg, then also put cursors where that value occurs."
 ;;
 ;; Socket Low Level
 ;;
-      
+
 (defun dinotrace-send-command (&rest commands)
   "Send a given configuration COMMAND to the dinotrace session."
   (cond ((not dinotrace-socket-name)
@@ -1278,9 +1270,9 @@ If prefix-arg, then also put cursors where that value occurs."
 	((string-match "^\\(.*\\) \\([0-9]+\\)$" dinotrace-socket-name)
 	 (setq dinotrace-socket
 	       (condition-case nil
-		   (open-network-stream 
+		   (open-network-stream
 		    "dinotrace" nil (match-string 1 dinotrace-socket-name)
-		    (string-to-int (match-string 2 dinotrace-socket-name)))
+		    (string-to-number (match-string 2 dinotrace-socket-name)))
 		 (file-error nil)))
 	 (cond ((not dinotrace-socket)
 		(error "Can't open socket.  Press a in Dinotrace, then C-x C-a a in Emacs"))
@@ -1292,7 +1284,7 @@ If prefix-arg, then also put cursors where that value occurs."
 	(t (error "Can't parse socket name"))
 	))
 ;;(dinotrace-send-command "refresh\n")
-	 
+
 ;;
 ;; Utilities
 ;;
@@ -1313,7 +1305,7 @@ If prefix-arg, then also put cursors where that value occurs."
 
 ;;
 ;; Install ourselves
-;; 
+;;
 
 (unless (assq 'dinotrace-mode minor-mode-alist)
   (setq minor-mode-alist
