@@ -1,4 +1,3 @@
-#ident "$Id: dt_cursor.c 768 2006-12-26 19:11:26Z wsnyder $"
 /******************************************************************************
  * DESCRIPTION: Dinotrace source: cursor requestors, events, etc
  *
@@ -6,7 +5,7 @@
  *
  * Author: Wilson Snyder <wsnyder@wsnyder.org>
  *
- * Code available from: http://www.veripool.com/dinotrace
+ * Code available from: http://www.veripool.org/dinotrace
  *
  ******************************************************************************
  *
@@ -40,7 +39,7 @@
  *
  * Dinotrace is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2, or (at your option)
+ * the Free Software Foundation; either version 3, or (at your option)
  * any later version.
  *
  * Dinotrace is distributed in the hope that it will be useful,
@@ -165,7 +164,7 @@ DCursor_t *cur_add (
 	else {
 	    prev_csr_ptr->next = new_csr_ptr;
 	}
-	
+
 	new_csr_ptr->next = csr_ptr;
 	new_csr_ptr->prev = prev_csr_ptr;
 	if (csr_ptr) csr_ptr->prev = new_csr_ptr;
@@ -430,7 +429,7 @@ char *cur_examine_string (
     }
     return (strg);
 }
-	
+
 
 /****************************** MENU OPTIONS ******************************/
 
@@ -653,12 +652,12 @@ void    cur_move_ev (
 	    last_x = em->x;
 	    XSetForeground (global->display, trace->gc, trace->xcolornums[0]);
 	    }
-	
+
 	/* if window was exposed, must redraw it */
 	if (event.type == Expose) win_expose_cb (0,trace);
 	/* if window was resized, must redraw it */
 	if (event.type == ConfigureNotify) win_resize_cb (0,trace);
-	
+
 	/* button released - calculate cursor position and leave the loop */
 	if (event.type == ButtonRelease || event.type == ButtonPress) {
 	    /* ButtonPress in case user is freaking out, some strange X behavior caused the ButtonRelease to be lost */
